@@ -28,6 +28,14 @@
  * SUCH DAMAGE.
  */
 
+#include "ns_turn_defs.h"     // for STRCPY, turn_time_t, uint8_t, uint32_t
+#include "ns_turn_msg.h"      // for convert_oauth_key_data, decode_oauth_t...
+#include "ns_turn_msg_defs.h" // for oauth_token, oauth_encrypted_block
+#include "ns_turn_utils.h"
+
+#include "apputils.h"
+#include "stun_buffer.h"
+
 #if defined(__unix__)
 #include <unistd.h>
 #endif
@@ -39,10 +47,6 @@
 #include <string.h>
 #include <time.h>
 
-#include "apputils.h"
-#include "ns_turn_utils.h"
-#include "stun_buffer.h"
-
 ////////////////////////////////////////////////////
 
 #define OAUTH_TOKEN_SIZE 1000 // TODO: find insted of 1000 the real max of encoded token length
@@ -80,7 +84,7 @@ static int setup_ikm_key(const char *kid, const char *ikm_key, const turn_time_t
   char err_msg[1025] = "\0";
   size_t err_msg_size = sizeof(err_msg) - 1;
 
-  if (convert_oauth_key_data(&okd, key, err_msg, err_msg_size) < 0) {
+  if (!convert_oauth_key_data(&okd, key, err_msg, err_msg_size)) {
     fprintf(stderr, "%s\n", err_msg);
     return -1;
   }
@@ -105,10 +109,11 @@ static int encode_token(const char *server_name, const char *gcm_nonce, const ch
   memset(&etoken, 0, sizeof(etoken));
 
   // TODO: avoid this hack
-  if (!*gcm_nonce)
+  if (!*gcm_nonce) {
     gcm_nonce = NULL;
+  }
 
-  if (encode_oauth_token((const uint8_t *)server_name, &etoken, &key, &ot, (const uint8_t *)gcm_nonce) < 0) {
+  if (!encode_oauth_token((const uint8_t *)server_name, &etoken, &key, &ot, (const uint8_t *)gcm_nonce)) {
     fprintf(stderr, "%s: cannot encode oauth token\n", __FUNCTION__);
     return -1;
   }
@@ -124,7 +129,7 @@ static int encode_token(const char *server_name, const char *gcm_nonce, const ch
 static int validate_decode_token(const char *server_name, const oauth_key key, const char *base64encoded_etoken,
                                  oauth_token *dot) {
 
-  memset((dot), 0, sizeof(*dot));
+  memset(dot, 0, sizeof(*dot));
 
   encoded_oauth_token etoken;
   memset(&etoken, 0, sizeof(etoken));
@@ -134,7 +139,7 @@ static int validate_decode_token(const char *server_name, const oauth_key key, c
   memcpy(etoken.token, tmp, etoken.size);
   free(tmp);
 
-  if (decode_oauth_token((const uint8_t *)server_name, &etoken, &key, dot) < 0) {
+  if (!decode_oauth_token((const uint8_t *)server_name, &etoken, &key, dot)) {
     fprintf(stderr, "%s: cannot decode oauth token\n", __FUNCTION__);
     return -1;
   } else {
@@ -370,8 +375,9 @@ int main(int argc, char **argv) {
     }
   }
 
-  for (i = optind; i < argc; i++)
+  for (i = optind; i < argc; i++) {
     printf("Non-option argument %s\n", argv[i]);
+  }
 
   if (optind > argc) {
     fprintf(stderr, "%s\n", Usage);
@@ -456,8 +462,9 @@ int main(int argc, char **argv) {
         oauth_token dot;
         if (validate_decode_token(server_name, key, base64encoded_etoken, &dot) == 0) {
           printf("-=Valid token!=-\n");
-          if (verbose_flag)
+          if (verbose_flag) {
             print_token_body(&dot);
+          }
         } else {
           fprintf(stderr, "Error during token validation and decoding\n");
           exit(-1);
