@@ -33,7 +33,7 @@
 #include "../mainrelay.h"
 
 #if !defined(TURN_NO_HIREDIS)
-#include "hiredis_libevent2.h"
+#include "../hiredis_libevent2.h"
 #include <hiredis/hiredis.h>
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -49,6 +49,7 @@ static void turnFreeRedisReply(void *reply) {
 struct _Ryconninfo {
   char *host;
   char *dbname;
+  char *user;
   char *password;
   unsigned int connect_timeout;
   unsigned int port;
@@ -58,28 +59,34 @@ typedef struct _Ryconninfo Ryconninfo;
 
 static void RyconninfoFree(Ryconninfo *co) {
   if (co) {
-    if (co->host)
+    if (co->host) {
       free(co->host);
-    if (co->dbname)
+    }
+    if (co->dbname) {
       free(co->dbname);
-    if (co->password)
+    }
+    if (co->user) {
+      free(co->user);
+    }
+    if (co->password) {
       free(co->password);
+    }
     memset(co, 0, sizeof(Ryconninfo));
     free(co);
   }
 }
 
 static Ryconninfo *RyconninfoParse(const char *userdb, char **errmsg) {
-  Ryconninfo *co = (Ryconninfo *)malloc(sizeof(Ryconninfo));
-  memset(co, 0, sizeof(Ryconninfo));
+  Ryconninfo *co = (Ryconninfo *)calloc(1, sizeof(Ryconninfo));
   if (userdb) {
     char *s0 = strdup(userdb);
     char *s = s0;
 
     while (s && *s) {
 
-      while (*s && (*s == ' '))
+      while (*s && (*s == ' ')) {
         ++s;
+      }
       char *snext = strstr(s, " ");
       if (snext) {
         *snext = 0;
@@ -97,47 +104,47 @@ static Ryconninfo *RyconninfoParse(const char *userdb, char **errmsg) {
       }
 
       *seq = 0;
-      if (!strcmp(s, "host"))
+      if (!strcmp(s, "host")) {
         co->host = strdup(seq + 1);
-      else if (!strcmp(s, "ip"))
+      } else if (!strcmp(s, "ip")) {
         co->host = strdup(seq + 1);
-      else if (!strcmp(s, "addr"))
+      } else if (!strcmp(s, "addr")) {
         co->host = strdup(seq + 1);
-      else if (!strcmp(s, "ipaddr"))
+      } else if (!strcmp(s, "ipaddr")) {
         co->host = strdup(seq + 1);
-      else if (!strcmp(s, "hostaddr"))
+      } else if (!strcmp(s, "hostaddr")) {
         co->host = strdup(seq + 1);
-      else if (!strcmp(s, "dbname"))
+      } else if (!strcmp(s, "dbname")) {
         co->dbname = strdup(seq + 1);
-      else if (!strcmp(s, "db"))
+      } else if (!strcmp(s, "db")) {
         co->dbname = strdup(seq + 1);
-      else if (!strcmp(s, "database"))
+      } else if (!strcmp(s, "database")) {
         co->dbname = strdup(seq + 1);
-      else if (!strcmp(s, "user"))
-        ;
-      else if (!strcmp(s, "uname"))
-        ;
-      else if (!strcmp(s, "name"))
-        ;
-      else if (!strcmp(s, "username"))
-        ;
-      else if (!strcmp(s, "password"))
+      } else if (!strcmp(s, "user")) {
+        co->user = strdup(seq + 1);
+      } else if (!strcmp(s, "uname")) {
+        co->user = strdup(seq + 1);
+      } else if (!strcmp(s, "name")) {
+        co->user = strdup(seq + 1);
+      } else if (!strcmp(s, "username")) {
+        co->user = strdup(seq + 1);
+      } else if (!strcmp(s, "password")) {
         co->password = strdup(seq + 1);
-      else if (!strcmp(s, "pwd"))
+      } else if (!strcmp(s, "pwd")) {
         co->password = strdup(seq + 1);
-      else if (!strcmp(s, "passwd"))
+      } else if (!strcmp(s, "passwd")) {
         co->password = strdup(seq + 1);
-      else if (!strcmp(s, "secret"))
+      } else if (!strcmp(s, "secret")) {
         co->password = strdup(seq + 1);
-      else if (!strcmp(s, "port"))
+      } else if (!strcmp(s, "port")) {
         co->port = (unsigned int)atoi(seq + 1);
-      else if (!strcmp(s, "p"))
+      } else if (!strcmp(s, "p")) {
         co->port = (unsigned int)atoi(seq + 1);
-      else if (!strcmp(s, "connect_timeout"))
+      } else if (!strcmp(s, "connect_timeout")) {
         co->connect_timeout = (unsigned int)atoi(seq + 1);
-      else if (!strcmp(s, "timeout"))
+      } else if (!strcmp(s, "timeout")) {
         co->connect_timeout = (unsigned int)atoi(seq + 1);
-      else {
+      } else {
         RyconninfoFree(co);
         co = NULL;
         if (errmsg) {
@@ -153,12 +160,12 @@ static Ryconninfo *RyconninfoParse(const char *userdb, char **errmsg) {
   }
 
   if (co) {
-    if (!(co->dbname))
+    if (!(co->dbname)) {
       co->dbname = strdup("0");
-    if (!(co->host))
+    }
+    if (!(co->host)) {
       co->host = strdup("127.0.0.1");
-    if (!(co->password))
-      co->password = strdup("");
+    }
   }
 
   return co;
@@ -195,13 +202,16 @@ redis_context_handle get_redis_async_connection(struct event_base *base, redis_s
 
         char ip[256] = "\0";
         int port = DEFAULT_REDIS_PORT;
-        if (co->host)
+        if (co->host) {
           STRCPY(ip, co->host);
-        if (!ip[0])
+        }
+        if (!ip[0]) {
           strncpy(ip, "127.0.0.1", sizeof(ip));
+        }
 
-        if (co->port)
+        if (co->port) {
           port = (int)(co->port);
+        }
 
         if (co->connect_timeout) {
           struct timeval tv;
@@ -215,8 +225,12 @@ redis_context_handle get_redis_async_connection(struct event_base *base, redis_s
         if (!rc) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Cannot initialize Redis DB async connection\n");
         } else {
-          if (co->password) {
-            turnFreeRedisReply(redisCommand(rc, "AUTH %s", co->password));
+          if (co->password && strlen(co->password)) {
+            if (co->user && strlen(co->user)) {
+              turnFreeRedisReply(redisCommand(rc, "AUTH %s %s", co->user, co->password));
+            } else {
+              turnFreeRedisReply(redisCommand(rc, "AUTH %s", co->password));
+            }
           }
           if (co->dbname) {
             turnFreeRedisReply(redisCommand(rc, "select %s", co->dbname));
@@ -233,8 +247,9 @@ redis_context_handle get_redis_async_connection(struct event_base *base, redis_s
               if (reply->type == REDIS_REPLY_ERROR) {
                 TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
               } else if (reply->type != REDIS_REPLY_ARRAY) {
-                if (reply->type != REDIS_REPLY_NIL)
+                if (reply->type != REDIS_REPLY_NIL) {
                   TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+                }
               } else {
                 size_t i;
                 for (i = 0; i < reply->elements; ++i) {
@@ -257,7 +272,7 @@ redis_context_handle get_redis_async_connection(struct event_base *base, redis_s
         }
       }
 
-      ret = redisLibeventAttach(base, co->host, co->port, co->password, atoi(co->dbname));
+      ret = redisLibeventAttach(base, co->host, co->port, co->user, co->password, atoi(co->dbname));
 
       if (!ret) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Cannot initialize Redis DB connection\n");
@@ -310,13 +325,16 @@ static redisContext *get_redis_connection(void) {
     } else {
       char ip[256] = "\0";
       int port = DEFAULT_REDIS_PORT;
-      if (co->host)
+      if (co->host) {
         STRCPY(ip, co->host);
-      if (!ip[0])
+      }
+      if (!ip[0]) {
         strncpy(ip, "127.0.0.1", sizeof(ip));
+      }
 
-      if (co->port)
+      if (co->port) {
         port = (int)(co->port);
+      }
 
       if (co->connect_timeout) {
         struct timeval tv;
@@ -334,8 +352,13 @@ static redisContext *get_redis_connection(void) {
           }
           redisFree(redisconnection);
           redisconnection = NULL;
-        } else if (co->password) {
-          void *reply = redisCommand(redisconnection, "AUTH %s", co->password);
+        } else if (co->password && strlen(co->password)) {
+          void *reply;
+          if (co->user && strlen(co->user)) {
+            reply = redisCommand(redisconnection, "AUTH %s %s", co->user, co->password);
+          } else {
+            reply = redisCommand(redisconnection, "AUTH %s", co->password);
+          }
           if (!reply) {
             if (redisconnection->err && redisconnection->errstr[0]) {
               TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Redis: %s\n", redisconnection->errstr);
@@ -391,11 +414,12 @@ static int set_redis_realm_opt(char *realm, const char *key, unsigned long *valu
 
     rget = (redisReply *)redisCommand(rc, s);
     if (rget) {
-      if (rget->type == REDIS_REPLY_ERROR)
+      if (rget->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", rget->str);
-      else if (rget->type != REDIS_REPLY_STRING) {
-        if (rget->type != REDIS_REPLY_NIL)
+      } else if (rget->type != REDIS_REPLY_STRING) {
+        if (rget->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", rget->type);
+        }
       } else {
         lock_realms();
         *value = (unsigned long)atol(rget->str);
@@ -418,11 +442,12 @@ static int redis_get_auth_secrets(secrets_list_t *sl, uint8_t *realm) {
     redisReply *reply = (redisReply *)redisCommand(rc, "smembers turn/realm/%s/secret", (char *)realm);
     if (reply) {
 
-      if (reply->type == REDIS_REPLY_ERROR)
+      if (reply->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-      else if (reply->type != REDIS_REPLY_ARRAY) {
-        if (reply->type != REDIS_REPLY_NIL)
+      } else if (reply->type != REDIS_REPLY_ARRAY) {
+        if (reply->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+        }
       } else {
         size_t i;
         for (i = 0; i < reply->elements; ++i) {
@@ -446,18 +471,18 @@ static int redis_get_user_key(uint8_t *usname, uint8_t *realm, hmackey_t key) {
     snprintf(s, sizeof(s), "get turn/realm/%s/user/%s/key", (char *)realm, usname);
     redisReply *rget = (redisReply *)redisCommand(rc, s);
     if (rget) {
-      if (rget->type == REDIS_REPLY_ERROR)
+      if (rget->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", rget->str);
-      else if (rget->type != REDIS_REPLY_STRING) {
-        if (rget->type != REDIS_REPLY_NIL)
+      } else if (rget->type != REDIS_REPLY_STRING) {
+        if (rget->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", rget->type);
+        }
       } else {
         size_t sz = get_hmackey_size(SHATYPE_DEFAULT);
         if (strlen(rget->str) < sz * 2) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Wrong key format: %s, user %s\n", rget->str, usname);
-        } else if (convert_string_key_to_binary(rget->str, key, sz) < 0) {
-          TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Wrong key: %s, user %s\n", rget->str, usname);
         } else {
+          convert_string_key_to_binary(rget->str, key, sz);
           ret = 0;
         }
       }
@@ -477,11 +502,12 @@ static int redis_get_oauth_key(const uint8_t *kid, oauth_key_data_raw *key) {
     snprintf(s, sizeof(s), "hgetall turn/oauth/kid/%s", (const char *)kid);
     redisReply *reply = (redisReply *)redisCommand(rc, s);
     if (reply) {
-      if (reply->type == REDIS_REPLY_ERROR)
+      if (reply->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-      else if (reply->type != REDIS_REPLY_ARRAY) {
-        if (reply->type != REDIS_REPLY_NIL)
+      } else if (reply->type != REDIS_REPLY_ARRAY) {
+        if (reply->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+        }
       } else if (reply->elements > 1) {
         size_t i;
         for (i = 0; i < (reply->elements) / 2; ++i) {
@@ -572,8 +598,9 @@ static int redis_list_users(uint8_t *realm, secrets_list_t *users, secrets_list_
   redisContext *rc = get_redis_connection();
 
   uint8_t realm0[STUN_MAX_REALM_SIZE + 1] = "\0";
-  if (!realm)
+  if (!realm) {
     realm = realm0;
+  }
 
   if (rc) {
     secrets_list_t keys;
@@ -592,11 +619,12 @@ static int redis_list_users(uint8_t *realm, secrets_list_t *users, secrets_list_
 
       if (reply) {
 
-        if (reply->type == REDIS_REPLY_ERROR)
+        if (reply->type == REDIS_REPLY_ERROR) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-        else if (reply->type != REDIS_REPLY_ARRAY) {
-          if (reply->type != REDIS_REPLY_NIL)
+        } else if (reply->type != REDIS_REPLY_ARRAY) {
+          if (reply->type != REDIS_REPLY_NIL) {
             TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+          }
         } else {
           size_t i;
           for (i = 0; i < reply->elements; ++i) {
@@ -614,23 +642,27 @@ static int redis_list_users(uint8_t *realm, secrets_list_t *users, secrets_list_
       char *s = keys.secrets[isz];
 
       char *sh = strstr(s, "turn/realm/");
-      if (sh != s)
+      if (sh != s) {
         continue;
+      }
       sh += rhsz;
       char *st = strchr(sh, '/');
-      if (!st)
+      if (!st) {
         continue;
+      }
       *st = 0;
       char *sr = sh;
       ++st;
 
       sh = strstr(st, "user/");
-      if (sh != st)
+      if (sh != st) {
         continue;
+      }
       sh += uhsz;
       st = strchr(sh, '/');
-      if (!st)
+      if (!st) {
         continue;
+      }
       *st = 0;
       char *su = sh;
 
@@ -718,8 +750,9 @@ static int redis_list_secrets(uint8_t *realm, secrets_list_t *secrets, secrets_l
   int ret = -1;
 
   uint8_t realm0[STUN_MAX_REALM_SIZE + 1] = "\0";
-  if (!realm)
+  if (!realm) {
     realm = realm0;
+  }
 
   donot_print_connection_success = 1;
   redisContext *rc = get_redis_connection();
@@ -737,11 +770,12 @@ static int redis_list_secrets(uint8_t *realm, secrets_list_t *secrets, secrets_l
 
       init_secrets_list(&keys);
 
-      if (reply->type == REDIS_REPLY_ERROR)
+      if (reply->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-      else if (reply->type != REDIS_REPLY_ARRAY) {
-        if (reply->type != REDIS_REPLY_NIL)
+      } else if (reply->type != REDIS_REPLY_ARRAY) {
+        if (reply->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+        }
       } else {
         size_t i;
         for (i = 0; i < reply->elements; ++i) {
@@ -760,19 +794,22 @@ static int redis_list_secrets(uint8_t *realm, secrets_list_t *secrets, secrets_l
           } else if (rget->type == REDIS_REPLY_STRING) {
             printf("%s\n", rget->str);
           } else if (rget->type != REDIS_REPLY_ARRAY) {
-            if (rget->type != REDIS_REPLY_NIL)
+            if (rget->type != REDIS_REPLY_NIL) {
               TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", rget->type);
+            }
           } else {
 
             char *s = keys.secrets[isz];
 
             char *sh = strstr(s, "turn/realm/");
-            if (sh != s)
+            if (sh != s) {
               continue;
+            }
             sh += rhsz;
             char *st = strchr(sh, '/');
-            if (!st)
+            if (!st) {
               continue;
+            }
             *st = 0;
             const char *rval = sh;
 
@@ -840,8 +877,9 @@ static int redis_set_permission_ip(const char *kind, uint8_t *realm, const char
   int ret = -1;
 
   uint8_t realm0[STUN_MAX_REALM_SIZE + 1] = "\0";
-  if (!realm)
+  if (!realm) {
     realm = realm0;
+  }
 
   donot_print_connection_success = 1;
 
@@ -896,8 +934,9 @@ static int redis_list_origins(uint8_t *realm, secrets_list_t *origins, secrets_l
   int ret = -1;
 
   uint8_t realm0[STUN_MAX_REALM_SIZE + 1] = "\0";
-  if (!realm)
+  if (!realm) {
     realm = realm0;
+  }
 
   donot_print_connection_success = 1;
 
@@ -914,11 +953,12 @@ static int redis_list_origins(uint8_t *realm, secrets_list_t *origins, secrets_l
       reply = (redisReply *)redisCommand(rc, "keys turn/origin/*");
       if (reply) {
 
-        if (reply->type == REDIS_REPLY_ERROR)
+        if (reply->type == REDIS_REPLY_ERROR) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-        else if (reply->type != REDIS_REPLY_ARRAY) {
-          if (reply->type != REDIS_REPLY_NIL)
+        } else if (reply->type != REDIS_REPLY_ARRAY) {
+          if (reply->type != REDIS_REPLY_NIL) {
             TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+          }
         } else {
           size_t i;
           size_t offset = strlen("turn/origin/");
@@ -937,11 +977,12 @@ static int redis_list_origins(uint8_t *realm, secrets_list_t *origins, secrets_l
       reply = (redisReply *)redisCommand(rc, "get turn/origin/%s", o);
       if (reply) {
 
-        if (reply->type == REDIS_REPLY_ERROR)
+        if (reply->type == REDIS_REPLY_ERROR) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-        else if (reply->type != REDIS_REPLY_STRING) {
-          if (reply->type != REDIS_REPLY_NIL)
+        } else if (reply->type != REDIS_REPLY_STRING) {
+          if (reply->type != REDIS_REPLY_NIL) {
             TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+          }
         } else {
           if (!(realm && realm[0] && strcmp((char *)realm, reply->str))) {
             if (origins) {
@@ -970,10 +1011,11 @@ static int redis_set_realm_option_one(uint8_t *realm, unsigned long value, const
   if (rc) {
     char s[TURN_LONG_STRING_SIZE];
 
-    if (value > 0)
+    if (value > 0) {
       snprintf(s, sizeof(s), "set turn/realm/%s/%s %lu", (char *)realm, opt, (unsigned long)value);
-    else
+    } else {
       snprintf(s, sizeof(s), "del turn/realm/%s/%s", (char *)realm, opt);
+    }
 
     turnFreeRedisReply(redisCommand(rc, s));
     turnFreeRedisReply(redisCommand(rc, "save"));
@@ -1002,11 +1044,12 @@ static int redis_list_realm_options(uint8_t *realm) {
       }
       if (reply) {
 
-        if (reply->type == REDIS_REPLY_ERROR)
+        if (reply->type == REDIS_REPLY_ERROR) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-        else if (reply->type != REDIS_REPLY_ARRAY) {
-          if (reply->type != REDIS_REPLY_NIL)
+        } else if (reply->type != REDIS_REPLY_ARRAY) {
+          if (reply->type != REDIS_REPLY_NIL) {
             TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+          }
         } else {
           size_t i;
           for (i = 0; i < reply->elements; ++i) {
@@ -1028,11 +1071,12 @@ static int redis_list_realm_options(uint8_t *realm) {
       reply = (redisReply *)redisCommand(rc, "get %s", o);
       if (reply) {
 
-        if (reply->type == REDIS_REPLY_ERROR)
+        if (reply->type == REDIS_REPLY_ERROR) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-        else if (reply->type != REDIS_REPLY_STRING) {
-          if (reply->type != REDIS_REPLY_NIL)
+        } else if (reply->type != REDIS_REPLY_STRING) {
+          if (reply->type != REDIS_REPLY_NIL) {
             TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+          }
         } else {
           printf("%s = %s\n", o + offset, reply->str);
         }
@@ -1070,11 +1114,12 @@ static int redis_get_ip_list(const char *kind, ip_range_list_t *list) {
 
       init_secrets_list(&keys);
 
-      if (reply->type == REDIS_REPLY_ERROR)
+      if (reply->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-      else if (reply->type != REDIS_REPLY_ARRAY) {
-        if (reply->type != REDIS_REPLY_NIL)
+      } else if (reply->type != REDIS_REPLY_ARRAY) {
+        if (reply->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+        }
       } else {
         size_t i;
         for (i = 0; i < reply->elements; ++i) {
@@ -1103,8 +1148,9 @@ static int redis_get_ip_list(const char *kind, ip_range_list_t *list) {
           } else if (rget->type == REDIS_REPLY_STRING) {
             add_ip_list_range(rget->str, realm, list);
           } else if (rget->type != REDIS_REPLY_ARRAY) {
-            if (rget->type != REDIS_REPLY_NIL)
+            if (rget->type != REDIS_REPLY_NIL) {
               TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", rget->type);
+            }
           } else {
             size_t i;
             for (i = 0; i < rget->elements; ++i) {
@@ -1145,11 +1191,12 @@ static void redis_reread_realms(secrets_list_t *realms_list) {
 
       char s[1025];
 
-      if (reply->type == REDIS_REPLY_ERROR)
+      if (reply->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-      else if (reply->type != REDIS_REPLY_ARRAY) {
-        if (reply->type != REDIS_REPLY_NIL)
+      } else if (reply->type != REDIS_REPLY_ARRAY) {
+        if (reply->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+        }
       } else {
         size_t i;
         for (i = 0; i < reply->elements; ++i) {
@@ -1164,11 +1211,12 @@ static void redis_reread_realms(secrets_list_t *realms_list) {
         snprintf(s, sizeof(s), "get %s", keys.secrets[isz]);
         redisReply *rget = (redisReply *)redisCommand(rc, s);
         if (rget) {
-          if (rget->type == REDIS_REPLY_ERROR)
+          if (rget->type == REDIS_REPLY_ERROR) {
             TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", rget->str);
-          else if (rget->type != REDIS_REPLY_STRING) {
-            if (rget->type != REDIS_REPLY_NIL)
+          } else if (rget->type != REDIS_REPLY_STRING) {
+            if (rget->type != REDIS_REPLY_NIL) {
               TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", rget->type);
+            }
           } else {
             get_realm(rget->str);
             ur_string_map_value_type value = strdup(rget->str);
@@ -1243,11 +1291,12 @@ static int redis_get_admin_user(const uint8_t *usname, uint8_t *realm, password_
     snprintf(s, sizeof(s), "hgetall turn/admin_user/%s", (const char *)usname);
     redisReply *reply = (redisReply *)redisCommand(rc, s);
     if (reply) {
-      if (reply->type == REDIS_REPLY_ERROR)
+      if (reply->type == REDIS_REPLY_ERROR) {
         TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Error: %s\n", reply->str);
-      else if (reply->type != REDIS_REPLY_ARRAY) {
-        if (reply->type != REDIS_REPLY_NIL)
+      } else if (reply->type != REDIS_REPLY_ARRAY) {
+        if (reply->type != REDIS_REPLY_NIL) {
           TURN_LOG_FUNC(TURN_LOG_LEVEL_ERROR, "Unexpected type: %d\n", reply->type);
+        }
       } else if (reply->elements > 1) {
         size_t i;
         for (i = 0; i < (reply->elements) / 2; ++i) {
