@@ -252,7 +252,7 @@ union telnet_event_t {
     enum telnet_event_type_t _type; /*!< alias for type */
     const char *buffer;             /*!< byte buffer */
     size_t size;                    /*!< number of bytes in buffer */
-  } data;
+  } data;                           /*!< DATA and SEND */
 
   /*!
    * WARNING and ERROR events
@@ -264,7 +264,7 @@ union telnet_event_t {
     const char *msg;                /*!< error message string */
     int line;                       /*!< line of file error occured on */
     telnet_error_t errcode;         /*!< error code */
-  } error;
+  } error;                          /*!< WARNING and ERROR */
 
   /*!
    * command event: for IAC
@@ -272,7 +272,7 @@ union telnet_event_t {
   struct iac_t {
     enum telnet_event_type_t _type; /*!< alias for type */
     unsigned char cmd;              /*!< telnet command received */
-  } iac;
+  } iac;                            /*!< IAC */
 
   /*!
    * negotiation event: WILL, WONT, DO, DONT
@@ -280,7 +280,7 @@ union telnet_event_t {
   struct negotiate_t {
     enum telnet_event_type_t _type; /*!< alias for type */
     unsigned char telopt;           /*!< option being negotiated */
-  } neg;
+  } neg;                            /*!< WILL, WONT, DO, DONT */
 
   /*!
    * subnegotiation event
@@ -290,7 +290,7 @@ union telnet_event_t {
     const char *buffer;             /*!< data of sub-negotiation */
     size_t size;                    /*!< number of bytes in buffer */
     unsigned char telopt;           /*!< option code for negotiation */
-  } sub;
+  } sub;                            /*!< SB */
 
   /*!
    * ZMP event
@@ -299,7 +299,7 @@ union telnet_event_t {
     enum telnet_event_type_t _type; /*!< alias for type */
     const char **argv;              /*!< array of argument string */
     size_t argc;                    /*!< number of elements in argv */
-  } zmp;
+  } zmp;                            /*!< ZMP */
 
   /*!
    * TTYPE event
@@ -308,7 +308,7 @@ union telnet_event_t {
     enum telnet_event_type_t _type; /*!< alias for type */
     unsigned char cmd;              /*!< TELNET_TTYPE_IS or TELNET_TTYPE_SEND */
     const char *name;               /*!< terminal type name (IS only) */
-  } ttype;
+  } ttype;                          /*!< TTYPE */
 
   /*!
    * COMPRESS event
@@ -317,7 +317,7 @@ union telnet_event_t {
     enum telnet_event_type_t _type; /*!< alias for type */
     unsigned char state;            /*!< 1 if compression is enabled,
                                      0 if disabled */
-  } compress;
+  } compress;                       /*!< COMPRESS */
 
   /*!
    * ENVIRON/NEW-ENVIRON event
@@ -327,7 +327,7 @@ union telnet_event_t {
     const struct telnet_environ_t *values; /*!< array of variable values */
     size_t size;                           /*!< number of elements in values */
     unsigned char cmd;                     /*!< SEND, IS, or INFO */
-  } environ;
+  } environ;                               /*!< ENVIRON, NEW-ENVIRON */
 
   /*!
    * MSSP event
@@ -336,7 +336,7 @@ union telnet_event_t {
     enum telnet_event_type_t _type;        /*!< alias for type */
     const struct telnet_environ_t *values; /*!< array of variable values */
     size_t size;                           /*!< number of elements in values */
-  } mssp;
+  } mssp;                                  /*!< MSSP */
 };
 
 /*!
