@@ -65,7 +65,6 @@ void print_field5769(const char *name, const void *f0, size_t len) {
 }
 
 static int check_oauth(void) {
-
   const char server_name[33] = "blackdow.carleon.gov";
 
   size_t i_encs;
@@ -74,7 +73,7 @@ static int check_oauth(void) {
 
   size_t ltp_output_length = 0;
 
-  const char *base64encoded_ltp =
+  char *base64encoded_ltp =
       base64_encode((const unsigned char *)long_term_key, strlen(long_term_key), &ltp_output_length);
 
   const char mac_key[33] = "ZksjpweoixXmvn67534m";
@@ -90,13 +89,12 @@ static int check_oauth(void) {
 
   {
     {
-
       for (i_encs = 0; encs[i_encs]; ++i_encs) {
-
         printf("oauth token %s:", encs[i_encs]);
 
-        if (print_extra)
+        if (print_extra) {
           printf("\n");
+        }
 
         oauth_token ot;
         memset(&ot, 0, sizeof(ot));
@@ -129,9 +127,9 @@ static int check_oauth(void) {
             char err_msg[1025] = "\0";
             size_t err_msg_size = sizeof(err_msg) - 1;
 
-            if (convert_oauth_key_data(&okd, &key, err_msg, err_msg_size) < 0) {
+            if (!convert_oauth_key_data(&okd, &key, err_msg, err_msg_size)) {
               fprintf(stderr, "%s\n", err_msg);
-              return -1;
+              goto err;
             }
           }
         }
@@ -145,41 +143,41 @@ static int check_oauth(void) {
           encoded_oauth_token etoken;
           memset(&etoken, 0, sizeof(etoken));
 
-          if (encode_oauth_token((const uint8_t *)server_name, &etoken, &key, &ot, (const uint8_t *)gcm_nonce) < 0) {
+          if (!encode_oauth_token((const uint8_t *)server_name, &etoken, &key, &ot, (const uint8_t *)gcm_nonce)) {
             fprintf(stderr, "%s: cannot encode oauth token\n", __FUNCTION__);
-            return -1;
+            goto err;
           }
 
           if (print_extra) {
             print_field5769("encoded token", etoken.token, etoken.size);
           }
 
-          if (decode_oauth_token((const uint8_t *)server_name, &etoken, &key, &dot) < 0) {
+          if (!decode_oauth_token((const uint8_t *)server_name, &etoken, &key, &dot)) {
             fprintf(stderr, "%s: cannot decode oauth token\n", __FUNCTION__);
-            return -1;
+            goto err;
           }
         }
 
         if (strcmp((char *)ot.enc_block.mac_key, (char *)dot.enc_block.mac_key)) {
           fprintf(stderr, "%s: wrong mac key: %s, must be %s\n", __FUNCTION__, (char *)dot.enc_block.mac_key,
                   (char *)ot.enc_block.mac_key);
-          return -1;
+          goto err;
         }
 
         if (ot.enc_block.key_length != dot.enc_block.key_length) {
           fprintf(stderr, "%s: wrong key length: %d, must be %d\n", __FUNCTION__, (int)dot.enc_block.key_length,
                   (int)ot.enc_block.key_length);
-          return -1;
+          goto err;
         }
         if (ot.enc_block.timestamp != dot.enc_block.timestamp) {
           fprintf(stderr, "%s: wrong timestamp: %llu, must be %llu\n", __FUNCTION__,
                   (unsigned long long)dot.enc_block.timestamp, (unsigned long long)ot.enc_block.timestamp);
-          return -1;
+          goto err;
         }
         if (ot.enc_block.lifetime != dot.enc_block.lifetime) {
           fprintf(stderr, "%s: wrong lifetime: %lu, must be %lu\n", __FUNCTION__, (unsigned long)dot.enc_block.lifetime,
                   (unsigned long)ot.enc_block.lifetime);
-          return -1;
+          goto err;
         }
 
         printf("OK\n");
@@ -187,7 +185,16 @@ static int check_oauth(void) {
     }
   }
 
+  if (base64encoded_ltp) {
+    free(base64encoded_ltp);
+  }
   return 0;
+
+err:
+  if (base64encoded_ltp) {
+    free(base64encoded_ltp);
+  }
+  return -1;
 }
 
 //////////////////////////////////////////////////
@@ -200,8 +207,9 @@ int main(int argc, const char **argv) {
   UNUSED_ARG(argc);
   UNUSED_ARG(argv);
 
-  if (argc > 1)
+  if (argc > 1) {
     print_extra = 1;
+  }
 
   set_logfile("stdout");
   set_no_stdout_log(1);
@@ -451,8 +459,7 @@ int main(int argc, const char **argv) {
 
       printf("RFC 5769 IPv4 encoding result: ");
 
-      res = stun_attr_get_first_addr_str(buf, sizeof(respv4) - 1, STUN_ATTRIBUTE_XOR_MAPPED_ADDRESS, &addr4, NULL);
-      if (res < 0) {
+      if (!stun_attr_get_first_addr_str(buf, sizeof(respv4) - 1, STUN_ATTRIBUTE_XOR_MAPPED_ADDRESS, &addr4, NULL)) {
         printf("failure on message structure check\n");
         exit(-1);
       }
@@ -540,8 +547,7 @@ int main(int argc, const char **argv) {
 
       printf("RFC 5769 IPv6 encoding result: ");
 
-      res = stun_attr_get_first_addr_str(buf, sizeof(respv6) - 1, STUN_ATTRIBUTE_XOR_MAPPED_ADDRESS, &addr6, NULL);
-      if (res < 0) {
+      if (!stun_attr_get_first_addr_str(buf, sizeof(respv6) - 1, STUN_ATTRIBUTE_XOR_MAPPED_ADDRESS, &addr6, NULL)) {
         printf("failure on message structure check\n");
         exit(-1);
       }
@@ -557,8 +563,9 @@ int main(int argc, const char **argv) {
   }
 
   {
-    if (check_oauth() < 0)
+    if (check_oauth() < 0) {
       exit(-1);
+    }
   }
 
   return 0;
