@@ -426,9 +426,11 @@ static const double __ac_HASH_UPPER = 0.77;
  */
 static kh_inline khint_t __ac_X31_hash_string(const char *s) {
   khint_t h = (khint_t)*s;
-  if (h)
-    for (++s; *s; ++s)
+  if (h) {
+    for (++s; *s; ++s) {
       h = (h << 5) - h + (khint_t)*s;
+    }
+  }
   return h;
 }
 /*! @function
